cmoncrawl.aggregator.utils.ndjson
=================================

.. automodule:: cmoncrawl.aggregator.utils.ndjson

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Decoder
   
   

   
   
   



